<?php
function crop_upload_render_options() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.'));
    }

    $options = crop_upload_get_options();

    if (isset($_POST['crop_upload_update']) && check_admin_referer('crop-upload-options-update')) {
        $update_data = [
            'enabled' => $_POST['enabled'] ?? 'no',
            'width' => $_POST['width'] ?? $options['width'],
            'height' => $_POST['height'] ?? $options['height'],
            'quality' => $_POST['quality'] ?? $options['quality'],
            'position' => $_POST['position'] ?? $options['position']
        ];

        if (crop_upload_update_options($update_data)) {
            echo '<div class="updated"><p><strong>Settings saved.</strong></p></div>';
            $options = crop_upload_get_options();
        }
    }
    ?>
    <div class="wrap">
        <h2>Crop Image After Upload Settings</h2>
        
        <form method="post" action="">
            <?php wp_nonce_field('crop-upload-options-update'); ?>
            
            <table class="form-table">
                <tr>
                    <th scope="row">Enable Cropping</th>
                    <td>
                        <select name="enabled">
                            <option value="no" <?php selected($options['enabled'], false); ?>>No - do not crop images</option>
                            <option value="yes" <?php selected($options['enabled'], true); ?>>Yes - crop large images</option>
                        </select>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row">Target Dimensions</th>
                    <td>
                        <label>Width: <input type="number" name="width" value="<?php echo esc_attr($options['width']); ?>" class="small-text" min="1" /></label>
                        <label>Height: <input type="number" name="height" value="<?php echo esc_attr($options['height']); ?>" class="small-text" min="1" /></label>
                        <p class="description">Images will be cropped to these exact dimensions</p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row">Crop Position</th>
                    <td>
                        <select name="position">
                            <option value="center" <?php selected($options['position'], 'center'); ?>>Center</option>
                            <option value="top" <?php selected($options['position'], 'top'); ?>>Top</option>
                            <option value="bottom" <?php selected($options['position'], 'bottom'); ?>>Bottom</option>
                        </select>
                        <p class="description">Choose where to focus the crop</p>
                    </td>
                </tr>
                
                <tr>
                    <th scope="row">JPEG Quality</th>
                    <td>
                        <input type="number" name="quality" value="<?php echo esc_attr($options['quality']); ?>" class="small-text" min="1" max="100" />
                        <p class="description">1 = lowest quality, 100 = best quality</p>
                    </td>
                </tr>
            </table>
            
            <p class="submit">
                <input type="submit" name="crop_upload_update" class="button-primary" value="Save Changes" />
            </p>
        </form>
    </div>
    <?php
}